Step 5: Create a Median Image — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Step 5: Create a Median Image

A median image gets generated from the stack of undistorted single drizzle images.

`drizzlepac.createMedian.` `createMedian`(imgObjList, configObj, procSteps=None)

  Top-level interface to createMedian step called from top-level MultiDrizzle.

  This function parses the input parameters then calls the _median() function to median-combine the input images into a single image.

`drizzlepac.createMedian.` `getHelpAsString`()

  Return useful help from a file in the script directory called module.help

`drizzlepac.createMedian.` `median`(input=None, configObj=None, editpars=False, **inputDict)

  Create a median image from the seperately drizzled images.

`drizzlepac.createMedian.` `run`(configObj)

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »